﻿using System.Runtime.InteropServices;
using System.Windows.Input;
using Tetris.ViewsModels;

namespace Tetris.Views;

public partial class GameWindow
{
    public GameWindow()
    {
        AttachConsole(-1);
        InitializeComponent();
        DataContext = new GameViewModel();
    }

    public void Start(string userName) {
        GameViewModel.Game.UserName = userName;
        Show();
    }

    [DllImport("kernel32.dll")]
    private static extern bool AttachConsole(int dwProcessId);

    /// <summary>
    /// If the game is playing, and the user presses a arrow key, move the tetrominoe accordingly
    /// </summary>
    /// <param name="sender">The object that raised the event.</param>
    /// <param name="KeyEventArgs">The event arguments for the key press.</param>
    /// <returns>
    /// The key that is being pressed.
    /// </returns>
    private void UIElement_OnKeyDown(object sender, KeyEventArgs e)
    {
        if (!GameViewModel.Game.Playing)
            return;
        
        switch (e.Key)
        {
            // If key is space
            case Key.Space:
                GameViewModel.Game.CurrentTetrominoe?.RotateRight();
                break;
            // If key is down
            case Key.Down:
                GameViewModel.Game.CurrentTetrominoe?.GoDown();
                break;
            // If key is left
            case Key.Left:
                GameViewModel.Game.CurrentTetrominoe?.GoLeft();
                break;
            // If key is right
            case Key.Right:
                GameViewModel.Game.CurrentTetrominoe?.GoRight();
                break;
        }
    }
}